=========================================================
``psyclone.tests.psyir.frontend.fparser2_container_test``
=========================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_container_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_container_test
